@@ -1,12 +1,3 @@
-## ---- cache=TRUE---------------------------------------------------------
-  # library(ggsom)
-  # suppressMessages(library(tidyverse))
-  # suppressMessages(library(kohonen))
-  # library(ggthemes)
-  # 
-  # iris_som <- kohonen::som(scale(iris[1:4]), grid = somgrid(6, 4, "rectangular"))
-
-
 ## ---- fig.height=8, fig.width=7, fig.align='center'----------------------
 library(ggsom)
 suppressMessages(library(tidyverse))
@@ -23,6 +14,16 @@ suppressMessages(library(tidyverse))
 suppressMessages(library(kohonen))
 library(ggthemes)
 
+iris_som <-
+kohonen::som(scale(iris[1:4]), grid = somgrid(6, 4, "rectangular"))
+ggsom::ggsom_line(aes_som(iris_som), FALSE)
+
+## ---- fig.height=8, fig.width=7, fig.align='center'----------------------
+library(ggsom)
+suppressMessages(library(tidyverse))
+suppressMessages(library(kohonen))
+library(ggthemes)
+
 iris_som <-
 kohonen::som(scale(iris[1:4]), grid = somgrid(6, 4, "rectangular"))
 ggsom_ribbon(aes_som(iris_som, cutree_value = 2) , TRUE)
